==> vdr-plugin-webvideo_0.2.1.orig.tar.gz: webvideo-0.2.1/src/vdr-plugin/request.h <==
/*
 * request.h: Web video plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id$
 */

#ifndef __WEBVIDEO_REQUEST_H
#define __WEBVIDEO_REQUEST_H

#include <vdr/tools.h>
#include <libwebvi.h>
#include "buffer.h"

enum eRequestType { REQT_NONE, REQT_MENU, REQT_FILE, REQT_STREAM };

// --- cDownloadProgress ---------------------------------------------------

class cDownloadProgress {
private:
  char *name;
  long downloaded;
  long total;
  long id;
public:
  cDownloadProgress(const char *title, long downloadedbytes, 
                    long totalbytes, long downloadid);
  ~cDownloadProgress();

  long GetDownloadID() { return id; }
  const char *GetTitle();
  float GetPercentage();
};

// --- cMenuRequest ----------------------------------------------------

class cMenuRequest {
private:
  int reqID;
  bool aborted;
  bool finished;
  int status;
  cString statusPharse;

protected:
  WebviCtx webvi;
  WebviHandle handle;
  char *wvtref;
  cMemoryBuffer inBuffer;

  virtual ssize_t WriteData(const char *ptr, size_t len);
  virtual WebviHandle PrepareHandle();
  static ssize_t WriteCallback(const char *ptr, size_t len, void *request);

public:
  cMenuRequest(int ID, const char *wvtreference);
  virtual ~cMenuRequest();

  int GetID() { return reqID; }
  WebviHandle GetHandle() { return handle; }

  bool Start(WebviCtx webvictx);
  virtual void RequestDone(int errorcode, cString pharse);
  bool IsFinished() { return finished; }
  void Abort();
  bool IsAborted() { return aborted; }

  // Return true if the lastest status code indicates success.
  bool Success();
  // Return the status code
  int GetStatusCode() { return status; }
  // Return the response pharse
  cString GetStatusPharse();

  virtual eRequestType GetType() { return REQT_MENU; }

  // Return the content of the reponse message
  virtual cString GetResponse();
};

// --- cFileDownloadRequest ------------------------------------------------

class cFileDownloadRequest : public cMenuRequest {
private:
  char *destdir;
  char *title;
  long bytesDownloaded;
  long contentLength;
  cUnbufferedFile *destfile;

protected:
  virtual WebviHandle PrepareHandle();
  virtual ssize_t WriteData(const char *ptr, size_t len);
  bool OpenDestFile();
  char *GetExtension(const char *contentType, const char *url);

public:
  cFileDownloadRequest(int ID, const char *streamref, 
                       const char *destdir);
  virtual ~cFileDownloadRequest();

  eRequestType GetType() { return REQT_FILE; }
  void RequestDone(int errorcode, cString pharse);

  cDownloadProgress *GetProgress(long downloadid);
};

// --- cStreamUrlRequest ---------------------------------------------------

class cStreamUrlRequest : public cMenuRequest {
protected:
  virtual WebviHandle PrepareHandle();

public:
  cStreamUrlRequest(int ID, const char *ref) : cMenuRequest(ID, ref) {}

  eRequestType GetType() { return REQT_STREAM; }
};

// --- cRequestVector ------------------------------------------------------

class cRequestVector : public cVector<cMenuRequest *> {
public:
  cRequestVector(int Allocated = 10) : cVector<cMenuRequest *>(Allocated) {}

  cMenuRequest *FindByHandle(WebviHandle handle);
};

#endif

==> vdr-plugin-webvideo_0.2.2.orig.tar.gz: webvideo-0.2.2/src/vdr-plugin/request.h <==
/*
 * request.h: Web video plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id$
 */

#ifndef __WEBVIDEO_REQUEST_H
#define __WEBVIDEO_REQUEST_H

#include <vdr/tools.h>
#include <libwebvi.h>
#include "buffer.h"

enum eRequestType { REQT_NONE, REQT_MENU, REQT_FILE, REQT_STREAM };
typedef void * tProgressID;

// --- cDownloadProgress ---------------------------------------------------

class cDownloadProgress {
private:
  char *name;
  long downloaded;
  long total;
  tProgressID id;
public:
  cDownloadProgress(const char *title, long downloadedbytes, 
                    long totalbytes, tProgressID downloadid);
  ~cDownloadProgress();

  tProgressID GetDownloadID() { return id; }
  const char *GetTitle();
  float GetPercentage();
};

// --- cMenuRequest ----------------------------------------------------

class cMenuRequest {
private:
  int reqID;
  bool aborted;
  bool finished;
  int status;
  cString statusPharse;

protected:
  WebviCtx webvi;
  WebviHandle handle;
  char *wvtref;
  cMemoryBuffer inBuffer;

  virtual ssize_t WriteData(const char *ptr, size_t len);
  virtual WebviHandle PrepareHandle();
  static ssize_t WriteCallback(const char *ptr, size_t len, void *request);

public:
  cMenuRequest(int ID, const char *wvtreference);
  virtual ~cMenuRequest();

  int GetID() { return reqID; }
  WebviHandle GetHandle() { return handle; }

  bool Start(WebviCtx webvictx);
  virtual void RequestDone(int errorcode, cString pharse);
  bool IsFinished() { return finished; }
  void Abort();
  bool IsAborted() { return aborted; }

  // Return true if the lastest status code indicates success.
  bool Success();
  // Return the status code
  int GetStatusCode() { return status; }
  // Return the response pharse
  cString GetStatusPharse();

  virtual eRequestType GetType() { return REQT_MENU; }

  // Return the content of the reponse message
  virtual cString GetResponse();
};

// --- cFileDownloadRequest ------------------------------------------------

class cFileDownloadRequest : public cMenuRequest {
private:
  char *destdir;
  char *title;
  long bytesDownloaded;
  long contentLength;
  cUnbufferedFile *destfile;

protected:
  virtual WebviHandle PrepareHandle();
  virtual ssize_t WriteData(const char *ptr, size_t len);
  bool OpenDestFile();
  char *GetExtension(const char *contentType, const char *url);

public:
  cFileDownloadRequest(int ID, const char *streamref, 
                       const char *destdir);
  virtual ~cFileDownloadRequest();

  eRequestType GetType() { return REQT_FILE; }
  void RequestDone(int errorcode, cString pharse);

  cDownloadProgress *GetProgress(tProgressID downloadid);
};

// --- cStreamUrlRequest ---------------------------------------------------

class cStreamUrlRequest : public cMenuRequest {
protected:
  virtual WebviHandle PrepareHandle();

public:
  cStreamUrlRequest(int ID, const char *ref) : cMenuRequest(ID, ref) {}

  eRequestType GetType() { return REQT_STREAM; }
};

// --- cRequestVector ------------------------------------------------------

class cRequestVector : public cVector<cMenuRequest *> {
public:
  cRequestVector(int Allocated = 10) : cVector<cMenuRequest *>(Allocated) {}

  cMenuRequest *FindByHandle(WebviHandle handle);
};

#endif
